@@ -1,8 +1,10 @@
 # xerparser
 # account.py
 
+from typing import Self
+
 from xerparser.schemas._node import Node
-from xerparser.src.validators import optional_int
+from xerparser.src.validators import int_or_zero
 
 
 class ACCOUNT(Node):
@@ -16,13 +18,12 @@ class ACCOUNT(Node):
             data["acct_short_name"],
             data["acct_name"],
             data["parent_acct_id"],
+            int_or_zero(data["acct_seq_num"]),
         )
         self.description: str = _check_description(data["acct_descr"])
         """Cost Account Description"""
-        self.seq_num: int | None = optional_int(data["acct_seq_num"])
-        """Sort Order"""
 
-    def __eq__(self, __o: "ACCOUNT") -> bool:
+    def __eq__(self, __o: Self) -> bool:
         if __o is None:
             return False
         return self.name == __o.name and self.full_code == __o.full_code
