@@ -4,12 +4,11 @@
 from datetime import datetime
 from enum import Enum
 from functools import cached_property
-from typing import Any
+from typing import Any, Self
 
 from xerparser.schemas.actvcode import ACTVCODE
 from xerparser.schemas.actvtype import ACTVTYPE
 from xerparser.schemas.calendars import CALENDAR
-from xerparser.schemas.projwbs import PROJWBS
 from xerparser.schemas.taskfin import TASKFIN
 from xerparser.schemas.taskmemo import TASKMEMO
 from xerparser.schemas.taskrsrc import TASKRSRC
@@ -100,10 +99,11 @@ class TASK:
         def is_wbs(self) -> bool:
             return self is self.TT_WBS
 
-    def __init__(self, calendar: CALENDAR, wbs: PROJWBS, **data: str) -> None:
+    def __init__(self, calendar: CALENDAR, wbs, **data: str) -> None:
+        from xerparser.schemas.projwbs import PROJWBS
+
         self.uid: str = data["task_id"]
         """Unique Table ID"""
-
         # Foreign keys
         self.proj_id: str = data["proj_id"]
         """Foreign Key for Project"""
@@ -113,7 +113,9 @@ class TASK:
         """Foreign Key for Calendar"""
 
         # General Task info
-        self.phys_complete_pct: float = float(data["phys_complete_pct"])
+        self.phys_complete_pct: float = (
+            float(data["phys_complete_pct"].replace(",", ".")) / 100
+        )
         """Activity physical percent complete"""
         self.complete_pct_type: str = data["complete_pct_type"]
         """Activity percent complete type: duration, physical, or units"""
@@ -134,8 +136,12 @@ class TASK:
             data["total_float_hr_cnt"]
         )
         self.free_float_hr_cnt: float | None = optional_float(data["free_float_hr_cnt"])
-        self.remain_drtn_hr_cnt: float = float(data["remain_drtn_hr_cnt"])
-        self.target_drtn_hr_cnt: float = float(data["target_drtn_hr_cnt"])
+        self.remain_drtn_hr_cnt: float = float(
+            data["remain_drtn_hr_cnt"].replace(",", ".")
+        )
+        self.target_drtn_hr_cnt: float = float(
+            data["target_drtn_hr_cnt"].replace(",", ".")
+        )
         self.float_path: int | None = optional_int(data["float_path"])
         self.float_path_order: int | None = optional_int(data["float_path_order"])
         self.is_longest_path: bool = data["driving_path_flag"] == "Y"
@@ -164,8 +170,8 @@ class TASK:
         )
         self.suspend_date: datetime | None = optional_date(data["suspend_date"])
         self.resume_date: datetime | None = optional_date(data["resume_date"])
-        self.create_date: datetime = datetime.strptime(data["create_date"], date_format)
-        self.update_date: datetime = datetime.strptime(data["update_date"], date_format)
+        self.create_date: datetime | None = optional_date(data["create_date"])
+        self.update_date: datetime | None = optional_date(data["update_date"])
 
         # Constraints
         self.cstr_date: datetime | None = optional_date(data["cstr_date"])
@@ -183,7 +189,7 @@ class TASK:
         self.activity_codes: dict[ACTVTYPE, ACTVCODE] = {}
         self.user_defined_fields: dict[UDFTYPE, Any] = {}
         self.calendar: CALENDAR = calendar
-        self.wbs: PROJWBS = self._valid_projwbs(wbs)
+        self.wbs: PROJWBS = wbs
         self.memos: list[TASKMEMO] = []
         self.resources: dict[str, TASKRSRC] = {}
         self.predecessors: list["LinkToTask"] = []
@@ -243,6 +249,11 @@ class TASK:
             },
         }
 
+    @property
+    @rounded()
+    def cost_variance(self) -> float:
+        return sum(res.cost_variance for res in self.resources.values())
+
     @property
     def duration(self) -> int:
         """
@@ -258,6 +269,18 @@ class TASK:
             return self.remaining_duration
         return self.original_duration
 
+    @property
+    @rounded(ndigits=4)
+    def duration_percent_complete(self) -> float:
+        """Duration percent complete calculated as a remaining duration / original duration"""
+        if self.remain_drtn_hr_cnt is None or self.status.is_completed:
+            return 1.0
+        if self.status.is_not_started or self.original_duration == 0:
+            return 0.0
+        if self.remain_drtn_hr_cnt >= self.target_drtn_hr_cnt:
+            return 0.0
+        return 1 - self.remain_drtn_hr_cnt / self.target_drtn_hr_cnt
+
     @property
     def finish(self) -> datetime:
         """Calculated activity finish date (Actual Finish or Early Finish)"""
@@ -288,25 +311,15 @@ class TASK:
     @cached_property
     @rounded(ndigits=4)
     def percent_complete(self) -> float:
+        """Activity percent complete based on the type of percent complete"""
         if self.percent_type is TASK.PercentType.CP_Phys:
-            return self.phys_complete_pct / 100
+            return self.phys_complete_pct
 
         if self.percent_type is TASK.PercentType.CP_Drtn:
-            if self.remain_drtn_hr_cnt is None or self.status.is_completed:
-                return 1.0
-            if self.status.is_not_started or self.original_duration == 0:
-                return 0.0
-            if self.remain_drtn_hr_cnt >= self.target_drtn_hr_cnt:
-                return 0.0
-
-            return 1 - self.remain_drtn_hr_cnt / self.target_drtn_hr_cnt
+            return self.duration_percent_complete
 
         if self.percent_type is TASK.PercentType.CP_Units:
-            target_units = self.target_work_qty + self.target_equip_qty
-            if target_units == 0:
-                return 0.0
-            actual_units = self.act_work_qty + self.act_equip_qty
-            return 1 - actual_units / target_units
+            return self.units_percent_complete
 
         raise ValueError(
             f"Could not calculate percent compelete for task {self.task_code}"
@@ -440,14 +453,14 @@ class TASK:
             return
         return int(self.total_float_hr_cnt / 8)
 
-    def _valid_projwbs(self, value: PROJWBS) -> PROJWBS:
-        if not isinstance(value, PROJWBS):
-            raise TypeError(f"Expected <class PROJWBS>; got {type(value)}")
-        if value.uid != self.wbs_id:
-            raise ValueError(
-                f"WBS unique id {value.uid} does not match wbs_id {self.wbs_id}"
-            )
-        return value
+    @property
+    @rounded(ndigits=4)
+    def units_percent_complete(self) -> float:
+        """Units percent complete calculated as a remaining units / original units"""
+        if (target_units := self.target_work_qty + self.target_equip_qty) == 0:
+            return 0.0
+        actual_units = self.act_work_qty + self.act_equip_qty
+        return 1 - actual_units / target_units
 
 
 class LinkToTask:
@@ -464,8 +477,14 @@ class LinkToTask:
         self.link: str = link
         self.lag: int = lag_days
 
-    def __eq__(self, __o: "LinkToTask") -> bool:
+    def __eq__(self, __o: Self) -> bool:
         return all((self.task == __o.task, self.link == __o.link))
 
     def __hash__(self) -> int:
         return hash((self.task, self.link))
+
+    def __repr__(self) -> str:
+        return f"<{self.task.task_code}[{self.link}:{self.lag}]>"
+
+    def __str__(self) -> str:
+        return f"{self.task.task_code}[{self.link}:{self.lag}]"
