@@ -8,25 +8,6 @@ from xerparser.src.validators import float_or_zero
 class TRSRCFIN:
     """
     A class to represent a Activity Resource Assignment Past Period Actuals
-
-    ...
-
-    Attributes
-    ----------
-    act_cost: float
-        Past Period Acutal Cost
-    act_qty: float
-        Past Period Actual Unit Quantity
-    fin_dates_id: str
-        Foreign Key for Financial Period
-    proj_id: str
-        Foreign Key for Project
-    task_id: str
-        Foreign Key for Task
-    taskrsrc_id: str
-        Foreign Key to Task Resource Assignment
-    period: FINDATES
-        Financial Period
     """
 
     def __init__(self, period: FINDATES, **data) -> None:
@@ -53,11 +34,9 @@ class TRSRCFIN:
     def _valid_findates(self, value: FINDATES) -> FINDATES:
         """Validate assignment of Financial Period"""
         if not isinstance(value, FINDATES):
-            raise ValueError(
-                f"ValueError: expected <class FINDATES>; got {type(value)}"
-            )
+            raise ValueError(f"Expected <class FINDATES>; got {type(value)}")
         if value.uid != self.fin_dates_id:
             raise ValueError(
-                f"ValueError: Financial Period ID {value.uid} does not equal fin_dates_id {self.fin_dates_id}"
+                f"FINDATES {value.uid} does not equal fin_dates_id {self.fin_dates_id}"
             )
         return value
